@@ -307,12 +307,9 @@ class ConfigTest extends TestCase
 
     public function testProhibitedUrlsWarningVerifyPeer(): void
     {
-        $io = $this->getMockBuilder(IOInterface::class)->disableOriginalConstructor()->getMock();
+        $io = $this->getIOMock();
 
-        $io
-            ->expects($this->once())
-            ->method('writeError')
-            ->with($this->equalTo('<warning>Warning: Accessing example.org with verify_peer and verify_peer_name disabled.</warning>'));
+        $io->expects([['text' => '<warning>Warning: Accessing example.org with verify_peer and verify_peer_name disabled.</warning>']], true);
 
         $config = new Config(false);
         $config->prohibitUrlByConfig('https://example.org', $io, [
@@ -398,7 +395,7 @@ class ConfigTest extends TestCase
         ];
         foreach ($keys as $key) {
             $value = $config->get($key);
-            $this->assertIsArray($value);
+            $this->assertIsArray($value); // @phpstan-ignore-line - PHPStan knows that its an array for all given keys
             $this->assertCount(0, $value);
         }
     }
